itkwasm.int_types - itkwasm python documentation
Description: Module Contents: Classes:,, IntTypes,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.int_types`

## Module Contents

### Classes

`IntTypes` |

### API

class itkwasm.int_types.IntTypes

  Bases: `str`, `enum.Enum`

  Int8

    ‘int8’

  UInt8

    ‘uint8’

  Int16

    ‘int16’

  UInt16

    ‘uint16’

  Int32

    ‘int32’

  UInt32

    ‘uint32’

  Int64

    ‘int64’

  UInt64

    ‘uint64’

  SizeValueType

    ‘uint64’

  IdentifierType

    ‘uint64’

  IndexValueType

    ‘int64’

  OffsetValueType

    ‘int64’

  __str__()
  __repr__()